package dev.kske.minesweeper;

import java.awt.BorderLayout;
import java.awt.EventQueue;
import java.awt.event.KeyEvent;

import javax.swing.JButton;
import javax.swing.JFrame;
import javax.swing.JMenu;
import javax.swing.JMenuBar;
import javax.swing.JMenuItem;
import javax.swing.JOptionPane;

/**
 * Project: <strong>Minesweeper</strong><br>
 * File: <strong>Minesweeper.java</strong><br>
 * Created: <strong>21.03.2019</strong><br>
 * Author: <strong>Kai S. K. Engelbart</strong>
 */
public class Minesweeper {

	private static final String VERSION = "1.0 JE";

	private JFrame mframe;

	private Board board;

	/**
	 * Launch the application.
	 */
	public static void main(String[] args) {
		EventQueue.invokeLater(new Runnable() {

			public void run() {
				try {
					Minesweeper window = new Minesweeper();
					window.mframe.setVisible(true);
				} catch (Exception e) {
					e.printStackTrace();
				}
			}
		});
	}

	/**
	 * Create the application.
	 */
	public Minesweeper() {
		initialize();
	}

	/**
	 * Initialize the contents of the frame.
	 */
	private void initialize() {
		mframe = new JFrame();
		mframe.setResizable(false);
		mframe.setTitle("Minesweeper");
		mframe.setBounds(100, 100, 450, 300);
		mframe.setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);

		createMenuBar();

		board = new Board(0, 0, 10, 10, 10);
		mframe.getContentPane().add(board);

		JButton btnRestart = new JButton("Restart");
		mframe.getContentPane().add(btnRestart, BorderLayout.NORTH);
	}

	private void createMenuBar() {
		var menubar = new JMenuBar();

		var gameMenu = new JMenu("Game");
		var	aboutMenuItem	= new JMenuItem("About");

		var	easyMenuItem	= new JMenuItem("Easy");
		var	mediumMenuItem	= new JMenuItem("Medium");
		var	hardMenuItem	= new JMenuItem("Hard");
		var	customMenuItem	= new JMenuItem("Custom");

		gameMenu.setMnemonic(KeyEvent.VK_G);
		easyMenuItem.setMnemonic(KeyEvent.VK_E);
		mediumMenuItem.setMnemonic(KeyEvent.VK_M);
		hardMenuItem.setMnemonic(KeyEvent.VK_H);
		customMenuItem.setMnemonic(KeyEvent.VK_C);

		aboutMenuItem.addActionListener((event) -> {
			JOptionPane.showMessageDialog(board, "Minesweeper version " + VERSION + "\nby Kai S. K. Engelbart");
		});
		
		gameMenu.add(easyMenuItem);
		gameMenu.add(mediumMenuItem);
		gameMenu.add(hardMenuItem);
		gameMenu.addSeparator();
		gameMenu.add(customMenuItem);
		menubar.add(gameMenu);
		menubar.add(aboutMenuItem);

		mframe.setJMenuBar(menubar);
	}
}
